==> visitors-8.x-2.17.tar.gz: visitors/visitors_geoip/src/EventSubscriber/GeoIpVisitLogSubscriber.php <==
<?php

namespace Drupal\visitors_geoip\EventSubscriber;

use Drupal\Core\Utility\Error;
use Drupal\visitors\Event\VisitLogEvent;
use Drupal\visitors_geoip\VisitorsGeoIpInterface;
use GeoIp2\Exception\AddressNotFoundException;
use Psr\Log\LoggerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class UserLoginSubscriber.
 *
 * @package Drupal\visitors\EventSubscriber
 */
class GeoIpVisitLogSubscriber implements EventSubscriberInterface {

  /**
   * The GeoIP service.
   *
   * @var \Drupal\visitors_geoip\VisitorsGeoIpInterface
   */
  protected $geoip;

  /**
   * The logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The GeoIP service.
   *
   * @param \Drupal\visitors_geoip\VisitorsGeoIpInterface $geoip
   *   The GeoIP service.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   */
  public function __construct(VisitorsGeoIpInterface $geoip, LoggerInterface $logger) {
    $this->geoip = $geoip;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      // Static class constant => method on this class.
      VisitLogEvent::EVENT_NAME => 'onVisit',
    ];
  }

  /**
   * Subscribe to the user login event dispatched.
   *
   * @param \Drupal\visitors\Event\VisitLogEvent $event
   *   Our custom event object.
   */
  public function onVisit(VisitLogEvent $event) {

    try {
      $fields = $event->getFields();
      /** @var \GeoIp2\Model\City|null $geoip */
      $geoip = $this->geoip->city($fields['visitors_ip']);
      if (is_null($geoip)) {
        return NULL;
      }
      $geoip_data                   = [];
      $geoip_data['continent_code'] = $geoip->continent->code;
      $geoip_data['country_code']   = $geoip->country->isoCode;
      $geoip_data['region']         = $geoip->subdivisions[0]->isoCode;
      $geoip_data['country_name']   = $geoip->country->names['en'];
      $geoip_data['city']           = $geoip->city->names['en'];
      $geoip_data['postal_code']    = $geoip->postal->code;
      $geoip_data['latitude']       = $geoip->location->latitude;
      $geoip_data['longitude']      = $geoip->location->longitude;
      $geoip_data['area_code']      = $geoip->location->metroCode;

      $fields['location_continent_code'] = $geoip_data['continent_code'];
      $fields['location_country_code']   = $geoip_data['country_code'];
      $fields['location_country_name']   = $geoip_data['country_name'];
      $fields['location_region']         = $geoip_data['region'];
      $fields['location_city']           = $geoip_data['city'];
      $fields['location_postal_code']    = $geoip_data['postal_code'];
      $fields['location_latitude']       = $geoip_data['latitude'];
      $fields['location_longitude']      = $geoip_data['longitude'];
      $fields['location_area_code']      = $geoip_data['area_code'];

      $event->setFields($fields);
    }
    catch (AddressNotFoundException $e) {
      // Do nothing.
    }
    catch (\Exception $e) {
      if (version_compare(\Drupal::VERSION, '10.1', '>=')) {
        Error::logException($this->logger, $e);
      }
      else {
        // @phpstan-ignore-next-line
        watchdog_exception('visitors', $e);
      }
    }

  }

}

==> visitors-8.x-2.20.tar.gz: visitors/visitors_geoip/src/EventSubscriber/GeoIpVisitLogSubscriber.php <==
<?php

namespace Drupal\visitors_geoip\EventSubscriber;

use Drupal\Core\Utility\Error;
use Drupal\visitors\Event\VisitLogEvent;
use Drupal\visitors_geoip\VisitorsGeoIpInterface;
use GeoIp2\Exception\AddressNotFoundException;
use Psr\Log\LoggerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class UserLoginSubscriber.
 *
 * @package Drupal\visitors\EventSubscriber
 */
class GeoIpVisitLogSubscriber implements EventSubscriberInterface {

  /**
   * The GeoIP service.
   *
   * @var \Drupal\visitors_geoip\VisitorsGeoIpInterface
   */
  protected $geoip;

  /**
   * The logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * The GeoIP service.
   *
   * @param \Drupal\visitors_geoip\VisitorsGeoIpInterface $geoip
   *   The GeoIP service.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   */
  public function __construct(VisitorsGeoIpInterface $geoip, LoggerInterface $logger) {
    $this->geoip = $geoip;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      // Static class constant => method on this class.
      VisitLogEvent::EVENT_NAME => 'onVisit',
    ];
  }

  /**
   * Subscribe to the user login event dispatched.
   *
   * @param \Drupal\visitors\Event\VisitLogEvent $event
   *   Our custom event object.
   */
  public function onVisit(VisitLogEvent $event) {

    try {
      $fields = $event->getFields();
      /** @var \GeoIp2\Model\City|null $geoip */
      $geoip = $this->geoip->city($fields['visitors_ip']);
      if (is_null($geoip)) {
        return NULL;
      }
      $geoip_data                   = [];
      $geoip_data['continent_code'] = $geoip->continent->code;
      $geoip_data['country_code']   = $geoip->country->isoCode;
      $geoip_data['region']         = $geoip->subdivisions[0]->isoCode;
      $geoip_data['country_name']   = $geoip->country->names['en'];
      $geoip_data['city']           = $geoip->city->names['en'];
      $geoip_data['postal_code']    = $geoip->postal->code;
      $geoip_data['latitude']       = $geoip->location->latitude;
      $geoip_data['longitude']      = $geoip->location->longitude;
      $geoip_data['area_code']      = $geoip->location->metroCode;

      $fields['location_continent_code'] = $geoip_data['continent_code'];
      $fields['location_country_code']   = $geoip_data['country_code'];
      $fields['location_country_name']   = $geoip_data['country_name'];
      $fields['location_region']         = $geoip_data['region'];
      $fields['location_city']           = $geoip_data['city'];
      $fields['location_postal']         = $geoip_data['postal_code'];
      $fields['location_latitude']       = $geoip_data['latitude'];
      $fields['location_longitude']      = $geoip_data['longitude'];
      $fields['location_area_code']      = $geoip_data['area_code'];

      $event->setFields($fields);
    }
    catch (AddressNotFoundException $e) {
      // Do nothing.
    }
    catch (\Exception $e) {
      if (version_compare(\Drupal::VERSION, '10.1', '>=')) {
        Error::logException($this->logger, $e);
      }
      else {
        // @phpstan-ignore-next-line
        watchdog_exception('visitors', $e);
      }
    }

  }

}
